select xt.install_js('XM','UserPreference','xtuple', $$
  /* Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
     See www.xm.ple.com/CPAL for the full text of the software license. */

  XM.UserPreference = {
    options: ["PrintSettings"]
  };

$$ );

